
/* STATS.H  written by Wayne Pearson
   This Small C header file contains some first quadrant statistics.
   min()   returns the minimum value in the data array passed to it.
   max()   returns the maximum value in the data array passed to it.
   size()  returns the number of data points in the data array.
   occ()   returns the number of occurrences of a specified data value.
   span()  returns the relative span of values in the data array.
   lactd() returns the largest absolute contiguous temporal difference.
   sactd() returns the smallest absolute contiguous temporal difference.
   Valid function calls:
                         mn = min(m,mn);
                         mx = max(m,mx);
                         s1 = size(data1,s1);
                         o1 = occ(data1,255,o1); or  o1 = occ(data1,d1,o1);
                         p1 = span(data1,p1);
                         l1 = lactd(data1,l1);
                         a1 = sactd(data1,a1);
*/

min(dat_min,dt_mn)
                    int dat_min[],*dt_mn;
                  {
                    int datalen,min_val,min_lcv,data_val;
                    datalen = min_lcv = 0; min_val = 255;
                    datalen = size(dat_min,datalen);
                    while(min_lcv < datalen)
                          {
                            data_val = dat_min[min_lcv];
                            if(data_val < min_val) min_val = data_val;
                            ++min_lcv;
                          }
                     dt_mn = min_val;
                   }

max(dat_max,dt_mx)
                    int dat_max[],*dt_mx;
                  {
                    int dt_len,max_val,max_lcv,dt_val;
                    dt_len = max_lcv = max_val = 0;
                    dt_len = size(dat_max,dt_len);
                    while(max_lcv < dt_len)
                          {
                            dt_val = dat_max[max_lcv];
                            if(dt_val > max_val) max_val = dt_val;
                            ++max_lcv;
                          }
                     dt_mx = max_val;
                   }

size(dat_size,size_)
                     int dat_size[], *size_;
       {
         int l_cntr,ma_dat; l_cntr = 0; ma_dat = 1;
         while(ma_dat != 0) { ma_dat = dat_size[l_cntr]; ++l_cntr; }
         size_ = l_cntr - 1;
       }

occ(occ_dat,occ_val,occ_n)
                           int occ_dat[],occ_val,*occ_n;
                        {
                           int cho_ar,cho_n,cho_lcv,cho_len;
                           cho_n = cho_lcv = cho_len = 0;
                           cho_len = size(occ_dat,cho_len);
                           while(cho_lcv < cho_len)
                                 {
                                   cho_ar = occ_dat[cho_lcv]; ++cho_lcv;
                                   if(cho_ar == occ_val) ++cho_n;
                                 }
                           occ_n = cho_n;
                        }

span(span_dat,span_)
                      int span_dat[],*span_;
                    {
                      int s_min,s_max; s_min = s_max = 0;
                      s_min = min(span_dat,s_min);
                      s_max = max(span_dat,s_max);
                      span_ = s_max - s_min;
                    }

lactd(dt_lactd,lactd_)
                        int dt_lactd[],*lactd_;
                      {
                        int dat_sz,lctd_lcv,lctd_val,dt_val1,dt_val2,dt_valx;
                        dat_sz = lctd_lcv = lctd_val = 0;
                        dat_sz = size(dt_lactd,dat_sz);
                        while(lctd_lcv < (dat_sz - 1))
                              {
                                dt_val1 = dt_lactd[lctd_lcv];
                                dt_val2 = dt_lactd[lctd_lcv + 1];
                                if(dt_val2 > dt_val1)
                                   dt_valx = dt_val2 - dt_val1;
                                else dt_valx = dt_val1 - dt_val2;
                                if(dt_valx > lctd_val) lctd_val = dt_valx;
                                ++lctd_lcv;
                              }
                        lactd_ = lctd_val;
                      }

sactd(dt_sactd,sactd_)
                        int dt_sactd[],*sactd_;
                      {
                        int dt_sz,sctd_lcv,sctd_val,dt_vl1,dt_vl2,dt_vlx;
                        dt_sz = sctd_lcv = 0; sctd_val = 255;
                        dt_sz = size(dt_sactd,dt_sz);
                        while(sctd_lcv < (dt_sz - 1))
                              {
                                dt_vl1 = dt_sactd[sctd_lcv];
                                dt_vl2 = dt_sactd[sctd_lcv + 1];
                                if(dt_vl2 > dt_vl1)
                                   dt_vlx = dt_vl2 - dt_vl1;
                                else dt_vlx = dt_vl1 - dt_vl2;
                                if(dt_vlx < sctd_val) sctd_val = dt_vlx;
                                ++sctd_lcv;
                              }
                        sactd_ = sctd_val;
                      }









